@@ -1,7 +1,7 @@
 package App::CompleteUtils;
 
 our $DATE = '2014-12-27'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,7 +22,7 @@ App::CompleteUtils - Collection of CLI utilities for Dist::Zilla
 
 =head1 VERSION
 
-This document describes version 0.02 of App::CompleteUtils (from Perl distribution App-CompleteUtils), released on 2014-12-27.
+This document describes version 0.03 of App::CompleteUtils (from Perl distribution App-CompleteUtils), released on 2014-12-27.
 
 =head1 SYNOPSIS
 
@@ -33,9 +33,6 @@ This distribution provides several command-line utilities related to
 
 L<Complete>
 
-Frameworks you can test this with: L<Perinci::CmdLine>,
-L<Getopt::Long::Complete>, L<Getopt::Long::Subcommand>.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-CompleteUtils>.
